@@ -4,7 +4,7 @@ use solana_client::client_error::ClientError;
 pub enum Error {
     ClintError(String),
     NoGoodNodes,
-    Error(String)
+    Error(String),
 }
 
 impl From<ClientError> for Error {
@@ -17,4 +17,4 @@ impl From<String> for Error {
     fn from(e: String) -> Self {
         Error::Error(e)
     }
-}
\ No newline at end of file
+}
